@@ -1,3 +1,4 @@
+"""nbclient cli."""
 import logging
 import pathlib
 import sys
@@ -12,13 +13,13 @@ from nbclient import __version__
 
 from .client import NotebookClient
 
-nbclient_aliases = {
+nbclient_aliases: dict = {
     'timeout': 'NbClientApp.timeout',
     'startup_timeout': 'NbClientApp.startup_timeout',
     'kernel_name': 'NbClientApp.kernel_name',
 }
 
-nbclient_flags = {
+nbclient_flags: dict = {
     'allow-errors': (
         {
             'NbClientApp': {
@@ -35,12 +36,12 @@ class NbClientApp(JupyterApp):
     An application used to execute notebook files (``*.ipynb``)
     """
 
-    version = __version__
-    name = 'jupyter-run'
+    version = Unicode(__version__)
+    name = 'jupyter-execute'
     aliases = nbclient_aliases
     flags = nbclient_flags
 
-    description = Unicode("An application used to execute notebook files (*.ipynb)")
+    description = "An application used to execute notebook files (*.ipynb)"
     notebooks = List([], help="Path of notebooks to convert").tag(config=True)
     timeout: int = Integer(
         None,
@@ -68,7 +69,7 @@ class NbClientApp(JupyterApp):
         help=dedent(
             """
             When a cell raises an error the default behavior is that
-            execution is stopped and a `CellExecutionError`
+            execution is stopped and a :py:class:`nbclient.exceptions.CellExecutionError`
             is raised.
             If this flag is provided, errors are ignored and execution
             is continued until the end of the notebook.
@@ -99,6 +100,7 @@ class NbClientApp(JupyterApp):
 
     @catch_config_error
     def initialize(self, argv=None):
+        """Initialize the app."""
         super().initialize(argv)
 
         # Get notebooks to run
@@ -106,13 +108,13 @@ class NbClientApp(JupyterApp):
 
         # If there are none, throw an error
         if not self.notebooks:
-            print(f"{self.name}: error: expected path to notebook")
             sys.exit(-1)
 
         # Loop and run them one by one
         [self.run_notebook(path) for path in self.notebooks]
 
     def get_notebooks(self):
+        """Get the notebooks for the app."""
         # If notebooks were provided from the command line, use those
         if self.extra_args:
             notebooks = self.extra_args
@@ -124,6 +126,7 @@ class NbClientApp(JupyterApp):
         return notebooks
 
     def run_notebook(self, notebook_path):
+        """Run a notebook by path."""
         # Log it
         self.log.info(f"Executing {notebook_path}")
 
@@ -132,7 +135,7 @@ class NbClientApp(JupyterApp):
         # Get its parent directory so we can add it to the $PATH
         path = pathlib.Path(notebook_path).parent.absolute()
 
-        # Set the intput file paths
+        # Set the input file paths
         input_path = f"{name}.ipynb"
 
         # Open up the notebook we're going to run
@@ -154,21 +157,4 @@ class NbClientApp(JupyterApp):
         client.execute()
 
 
-class NbClientAlias(NbClientApp):
-    """
-    An alias to the run command.
-    """
-
-    name = 'jupyter-execute'
-
-    @catch_config_error
-    def initialize(self, argv=None):
-        print(
-            "This alias to `jupyter run` may be deprecated in the future. "
-            "Please switch to using `run`."
-        )
-        super().initialize(argv)
-
-
-run = NbClientApp.launch_instance
-execute = NbClientAlias.launch_instance
+main = NbClientApp.launch_instance
