@@ -5,6 +5,7 @@ import datetime
 import functools
 import os
 import re
+import sys
 import threading
 import warnings
 from base64 import b64decode, b64encode
@@ -323,7 +324,7 @@ def filter_messages_on_error_output(err_output):
             "Interrupt.ipynb",
             {
                 "kernel_name": "python",
-                "timeout": 1,
+                "timeout": 3,
                 "interrupt_on_timeout": True,
                 "allow_errors": True,
             },
@@ -708,8 +709,13 @@ while True: continue
         res['metadata']['path'] = os.path.dirname(filename)
         with pytest.raises(CellExecutionError) as exc:
             run_notebook(filename, {"allow_errors": False}, res)
-            self.assertIsInstance(str(exc.value), str)
-            assert "# üñîçø∂é" in str(exc.value)
+
+        assert isinstance(str(exc.value), str)
+        exc_str = strip_ansi(str(exc.value))
+        # FIXME: we seem to have an encoding problem on Windows
+        # same check in force_raise_errors
+        if not sys.platform.startswith("win"):
+            assert "# üñîçø∂é" in exc_str
 
     def test_force_raise_errors(self):
         """
@@ -721,8 +727,23 @@ while True: continue
         res['metadata']['path'] = os.path.dirname(filename)
         with pytest.raises(CellExecutionError) as exc:
             run_notebook(filename, {"force_raise_errors": True}, res)
-            self.assertIsInstance(str(exc.value), str)
-            assert "# üñîçø∂é" in str(exc.value)
+
+        # verify CellExecutionError contents
+        exc_str = strip_ansi(str(exc.value))
+        # print for better debugging with captured output
+        # print(exc_str)
+        assert "Exception: message" in exc_str
+        # FIXME: unicode handling seems to have a problem on Windows
+        # same check in allow_errors
+        if not sys.platform.startswith("win"):
+            assert "# üñîçø∂é" in exc_str
+        assert "stderr" in exc_str
+        assert "stdout" in exc_str
+        assert "hello\n" in exc_str
+        assert "errorred\n" in exc_str
+        # stricter check for stream output format
+        assert "\n".join(["", "----- stdout -----", "hello", "---"]) in exc_str
+        assert "\n".join(["", "----- stderr -----", "errorred", "---"]) in exc_str
 
     def test_reset_kernel_client(self):
         filename = os.path.join(current_dir, 'files', 'HelloWorld.ipynb')
